@@ -103,7 +103,10 @@ CATEGORY_MAP = {
     "itchio"         : "itch.io",
     "jpgfish"        : "JPG Fish",
     "kabeuchi"       : "かべうち",
+    "mangafire"      : "MangaFire",
+    "mangareader"    : "MangaReader",
     "mangataro"      : "MangaTaro",
+    "s3ndpics"       : "S3ND",
     "schalenetwork"  : "Schale Network",
     "leakgallery"    : "Leak Gallery",
     "livedoor"       : "livedoor Blog",
