@@ -12,8 +12,11 @@ __tests__ = (
     "#url"     : "https://bunkr.sk/a/Lktg9Keq",
     "#category": ("lolisafe", "bunkr", "album"),
     "#class"   : bunkr.BunkrAlbumExtractor,
-    "#results"     : "https://brg-bk.cdn.gigachad-cdn.ru/test-%E3%83%86%E3%82%B9%E3%83%88-%22%26%3E-QjgneIQv.png?n=test-%E3%83%86%E3%82%B9%E3%83%88-%22%26%3E.png",
-    "#sha1_content": "0c8768055e4e20e7c7259608b67799171b691140",
+    "#results"     : """https://brg-bk.cdn.gigachad-cdn.ru/test-テスト-"&>-QjgneIQv.png""",
+    "#sha1_content": (
+        "0c8768055e4e20e7c7259608b67799171b691140",
+        "961b25d85b5f5bd18cbe3e847ac55925f14d0286",
+    ),
 
     "album_id"   : "Lktg9Keq",
     "album_name" : "test テスト \"&>",
@@ -25,6 +28,7 @@ __tests__ = (
     "id"         : "QjgneIQv",
     "id_url"     : "1044478",
     "name"       : "test-テスト-\"&>",
+    "slug"       : "test-テスト-\"&>-QjgneIQv.png",
     "num"        : 1,
 },
 
@@ -33,9 +37,12 @@ __tests__ = (
     "#category": ("lolisafe", "bunkr", "album"),
     "#class"   : bunkr.BunkrAlbumExtractor,
     "#results"     : (
-        "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg?n=image.jpg",
+        "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg",
+    ),
+    "#sha1_content": (
+        "55998743751dfe008d0e95605114fcbfa7dc4de8",
+        "caf7c3d3439d94e83b3c24ddaf5a3a48aa057519",
     ),
-    "#sha1_content": "55998743751dfe008d0e95605114fcbfa7dc4de8",
 
     "album_id"   : "iXTTc1o2",
     "album_name" : "test2",
@@ -53,8 +60,7 @@ __tests__ = (
     "#category": ("lolisafe", "bunkr", "album"),
     "#class"   : bunkr.BunkrAlbumExtractor,
     "#pattern" : r"https://(i-)?meatballs.bunkr.ru/\w+",
-    "#range"   : "5-",
-    "#count"   : 3,
+    "#count"   : 4,
 },
 
 {
@@ -65,7 +71,9 @@ __tests__ = (
     "#count"   : 2,
 
     "id"    : "",
-    "id_url": {"UPKDHBf0CvrCe", "zQgSePr1f4HZ2"},
+    "id_url": {"43478756", "43478551"},
+    "slug"  : {"UPKDHBf0CvrCe", "zQgSePr1f4HZ2"},
+    "uuid"  : "iso:uuid",
 },
 
 {
@@ -191,16 +199,52 @@ __tests__ = (
     "#class"   : bunkr.BunkrAlbumExtractor,
 },
 
+{
+    "#url"     : "https://bunkr.cr/a/z5Xt6NqH",
+    "#comment" : "filenames (#8150)",
+    "#category": ("lolisafe", "bunkr", "album"),
+    "#class"   : bunkr.BunkrAlbumExtractor,
+    "#results" : (
+        "https://beer.bunkr.ru/acba241d-c1e8-40c3-aa73-94daf75fcd13.jpg",
+        "https://cake.bunkr.ru/e997f757-61dc-45be-bd61-b6998d813beb.jpg",
+        "https://cake.bunkr.ru/72f1e20b-72a5-43b0-8ab2-472016e1d767.mp4",
+    ),
+
+    "album_id"  : "z5Xt6NqH",
+    "album_name": "filename",
+    "album_size": "1.82 MB",
+    "count"     : 3,
+    "date"      : "type:datetime",
+    "extension" : {"jpg", "mp4"},
+    "file"      : str,
+    "id"        : "",
+    "name"      : str,
+    "num"       : range(1, 3),
+    "id_url"    : {"53118207", "53118010", "53117871"},
+    "size"      : {490885, 727670, 687238},
+    "slug"      : {"Nzt1ID7lsgwR4", "Bu0e2k6gOB5di", "PwrDbEgQODSls"},
+    "filename"  : {
+        "'\"'",
+        "😃",
+        """filename: !"#$%&\'()*+,-.0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]""",
+    },
+    "uuid"      : {
+        "acba241d-c1e8-40c3-aa73-94daf75fcd13",
+        "e997f757-61dc-45be-bd61-b6998d813beb",
+        "72f1e20b-72a5-43b0-8ab2-472016e1d767",
+    },
+},
+
 {
     "#url"     : "https://bunkr.black/i/image-sZrQUeOx.jpg",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results"     : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg?n=image.jpg",
+    "#results"     : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg",
     "#sha1_content": "55998743751dfe008d0e95605114fcbfa7dc4de8",
 
     "count"    : 1,
     "extension": "jpg",
-    "file"     : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg?n=image.jpg",
+    "file"     : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg",
     "filename" : "image-sZrQUeOx",
     "id"       : "sZrQUeOx",
     "name"     : "image",
@@ -211,19 +255,19 @@ __tests__ = (
     "#comment" : "/f/ URL",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results" : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg?n=image.jpg",
+    "#results" : "https://mlk-bk.cdn.gigachad-cdn.ru/image-sZrQUeOx.jpg",
 },
 
 {
     "#url"     : "https://bunkrrr.org/d/dJuETSzKLrUps",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results"     : "https://brg-bk.cdn.gigachad-cdn.ru/file-r5fmwjdd.zip?n=file.zip",
+    "#results"     : "https://brg-bk.cdn.gigachad-cdn.ru/file-r5fmwjdd.zip",
     "#sha1_content": "102ddd7894fe39b3843098fc51f972a0af938f45",
 
     "count"    : 1,
     "extension": "zip",
-    "file"     : "https://brg-bk.cdn.gigachad-cdn.ru/file-r5fmwjdd.zip?n=file.zip",
+    "file"     : "https://brg-bk.cdn.gigachad-cdn.ru/file-r5fmwjdd.zip",
     "filename" : "file-r5fmwjdd",
     "id"       : "r5fmwjdd",
     "id_url"   : "38792076",
@@ -235,7 +279,7 @@ __tests__ = (
     "#comment" : "redirect to '/f/rEeTUL8MXR17A' (#6790)",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results" : "https://meatballs.bunkr.ru/27-03-2024-Rp-0FfrropA.mp4",
+    "#results" : "https://c.bunkr-cache.se/hAVFkYK1bLbSaaKq/27-03-2024-Rp-0FfrropA.mp4",
 },
 
 {
@@ -243,10 +287,12 @@ __tests__ = (
     "#comment" : "correct 'name' from HTML (#6790)",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results" : "https://kebab.bunkr.ru/80ca5405-8b8d-4f9f-8167-8b046bb9dc67.mp4",
+    "#results" : "https://c.bunkr-cache.se/QlXezBjk2fCVVobM/80ca5405-8b8d-4f9f-8167-8b046bb9dc67.mp4",
 
     "id"       : "",
-    "id_url"   : "wYGCKbGhSvuAW",
+    "id_url"   : "41913002",
+    "slug"     : "wYGCKbGhSvuAW",
+    "uuid"     : "80ca5405-8b8d-4f9f-8167-8b046bb9dc67",
     "name"     : "0hwndshtfmj7hcbut1nd4_source",
     "filename" : "0hwndshtfmj7hcbut1nd4_source",
     "extension": "mp4",
@@ -257,12 +303,9 @@ __tests__ = (
     "#comment" : "file gone --- 403 error for main 'brg-bk.cdn.gigachad-cdn.ru' URL (#6732 #6972)",
     "#category": ("lolisafe", "bunkr", "media"),
     "#class"   : bunkr.BunkrMediaExtractor,
-    "#results"     : "https://brg-bk.cdn.gigachad-cdn.ru/IMG_47272f2c698d257fd22f4300ae98ec35929b-iEYVkLPQ.jpg?n=IMG_47272f2c698d257fd22f4300ae98ec35929b.jpg",
+    "#results"     : "https://brg-bk.cdn.gigachad-cdn.ru/IMG_47272f2c698d257fd22f4300ae98ec35929b-iEYVkLPQ.jpg",
     "#sha1_content": "f1c839743563828b250e48d485933a735a508527",
 
-    "_fallback": (
-        "https://i-burger.bunkr.ru/IMG_47272f2c698d257fd22f4300ae98ec35929b-iEYVkLPQ.jpg",
-    ),
     "_http_headers": {
         "Referer": "https://get.bunkrr.su/file/29682239",
     },
@@ -273,4 +316,18 @@ __tests__ = (
     "name"     : "IMG_47272f2c698d257fd22f4300ae98ec35929b",
 },
 
+{
+    "#url"     : "https://bunkr.pk/f/Nzt1ID7lsgwR4",
+    "#category": ("lolisafe", "bunkr", "media"),
+    "#class"   : bunkr.BunkrMediaExtractor,
+    "#results" : "https://beer.bunkr.ru/acba241d-c1e8-40c3-aa73-94daf75fcd13.jpg",
+
+    "filename"   : "'\"'",
+    "id"         : "",
+    "id_url"     : "53118207",
+    "name"       : "'\"'",
+    "slug"       : "Nzt1ID7lsgwR4",
+    "uuid"       : "acba241d-c1e8-40c3-aa73-94daf75fcd13",
+},
+
 )
