@@ -363,6 +363,16 @@ __tests__ = (
     "version": None,
 },
 
+{
+    "#url"     : "https://civitai.com/posts/20403514",
+    "#comment" : "mixed image & video (#8053)",
+    "#class"   : civitai.CivitaiPostExtractor,
+    "#results" : (
+        "https://image.civitai.com/xG1nkqKTMzGDvpLrqFT7WA/62dbebbe-48e9-4232-b4da-33c70d19683d/original=true/91967659.png",
+        "https://image.civitai.com/xG1nkqKTMzGDvpLrqFT7WA/e5786ddc-29b3-4a69-aec9-fba4dc2c78b5/quality=100/91967639.webm",
+    ),
+},
+
 {
     "#url"  : "https://civitai.com/tag/mecha",
     "#class": civitai.CivitaiTagExtractor,
@@ -378,6 +388,16 @@ __tests__ = (
     "#class": civitai.CivitaiImagesExtractor,
 },
 
+{
+    "#url"     : "https://civitai.com/videos",
+    "#class"   : civitai.CivitaiVideosExtractor,
+},
+
+{
+    "#url"     : "https://civitai.com/videos?tags=5169",
+    "#class"   : civitai.CivitaiVideosExtractor,
+},
+
 {
     "#url"  : "https://civitai.com/models",
     "#class": civitai.CivitaiModelsExtractor,
@@ -529,4 +549,149 @@ __tests__ = (
     "#auth"    : True,
 },
 
+{
+    "#url"     : "https://civitai.com/collections/11035869",
+    "#class"   : civitai.CivitaiCollectionExtractor,
+    "#results" : "https://image.civitai.com/xG1nkqKTMzGDvpLrqFT7WA/9b9c64b4-60de-4a9c-becd-a386ecf3fa7a/original=true/DailyWorldMorphChallenge_Base_0003.png",
+
+    "filename"       : "DailyWorldMorphChallenge_Base_0003",
+    "extension"      : "png",
+    "url"            : "https://image.civitai.com/xG1nkqKTMzGDvpLrqFT7WA/9b9c64b4-60de-4a9c-becd-a386ecf3fa7a/original=true/DailyWorldMorphChallenge_Base_0003.png",
+    "collection"     : {
+        "availability": "Public",
+        "description" : "",
+        "id"          : 11035869,
+        "image"       : None,
+        "metadata"    : {},
+        "mode"        : None,
+        "name"        : "Trees, Bonsai, and so one",
+        "nsfw"        : False,
+        "nsfwLevel"   : 1,
+        "read"        : "Public",
+        "tags"        : [],
+        "type"        : "Image",
+        "userId"      : 4831516,
+        "write"       : "Private",
+    },
+    "file"           : {
+        "acceptableMinor": False,
+        "availability"   : "Public",
+        "blockedFor"     : None,
+        "cosmetic"       : None,
+        "createdAt"      : "2025-04-30T20:20:44.015Z",
+        "date"           : "dt:2025-04-30 20:20:44",
+        "hasMeta"        : True,
+        "hasPositivePrompt": True,
+        "hash"           : "UHEfvNWC?dof00oc4Uae$,ofV}WFxeWCxwWV",
+        "height"         : 1152,
+        "hideMeta"       : False,
+        "id"             : 73339178,
+        "index"          : 1,
+        "ingestion"      : "Scanned",
+        "metadata"       : {
+            "hash"  : "UHEfvNWC?dof00oc4Uae$,ofV}WFxeWCxwWV",
+            "height": 1152,
+            "size"  : 1523677,
+            "width" : 896,
+        },
+        "mimeType"       : "image/png",
+        "minor"          : False,
+        "modelVersionId" : None,
+        "modelVersionIds": [],
+        "modelVersionIdsManual": [],
+        "name"           : "DailyWorldMorphChallenge_Base_0003.png",
+        "needsReview"    : None,
+        "nsfwLevel"      : 1,
+        "onSite"         : False,
+        "poi"            : False,
+        "postId"         : 16290779,
+        "postTitle"      : None,
+        "publishedAt"    : "2025-04-30T20:23:40.409Z",
+        "reactions"      : [],
+        "remixOfId"      : None,
+        "scannedAt"      : "2025-04-30T20:20:48.072Z",
+        "sortAt"         : "2025-04-30T20:23:40.409Z",
+        "stats"          : {
+            "collectedCountAllTime": 1,
+            "commentCountAllTime": 0,
+            "cryCountAllTime" : 1,
+            "dislikeCountAllTime": 0,
+            "heartCountAllTime": 1,
+            "laughCountAllTime": 0,
+            "likeCountAllTime": 5,
+            "tippedAmountCountAllTime": 0,
+            "viewCountAllTime": 0,
+        },
+        "tagIds"         : [
+            5248,
+            9143,
+            111839,
+            112019,
+            116352,
+            120250,
+            161904,
+            234268,
+        ],
+        "tags"           : None,
+        "thumbnailUrl"   : None,
+        "type"           : "image",
+        "url"            : "9b9c64b4-60de-4a9c-becd-a386ecf3fa7a",
+        "uuid"           : "9b9c64b4-60de-4a9c-becd-a386ecf3fa7a",
+        "width"          : 896,
+    },
+    "user"           : {
+        "cosmetics"     : list,
+        "deletedAt"     : None,
+        "id"            : 2624648,
+        "image"         : "ce0f7d5e-cc4a-41e2-8587-75d823c85ce9",
+        "profilePicture": None,
+        "username"      : "AIArtsChannel",
+    },
+    "user_collection": {
+        "cosmetics"     : [],
+        "deletedAt"     : None,
+        "id"            : 4831516,
+        "image"         : "https://lh3.googleusercontent.com/a/ACg8ocKeClAsD6kmHOATnC4Li1PLYw9-J41LCaVHdzcLLGZi9ElNUQ=s96-c",
+        "profilePicture": None,
+        "username"      : "TettyCo",
+    },
+},
+
+{
+    "#url"     : "https://civitai.com/collections/11453135",
+    "#class"   : civitai.CivitaiCollectionExtractor,
+    "#count"   : 12,
+
+    "collection"     : {
+        "availability": "Public",
+        "description" : "",
+        "id"          : 11453135,
+        "image"       : None,
+        "metadata"    : {},
+        "mode"        : None,
+        "name"        : "Sakura Trees",
+        "nsfw"        : False,
+        "nsfwLevel"   : 3,
+        "read"        : "Public",
+        "tags"        : [],
+        "type"        : "Image",
+        "userId"      : 8511981,
+        "write"       : "Private",
+    },
+},
+
+{
+    "#url"     : "https://civitai.com/user/SakuraCherryBlossoms/collections",
+    "#class"   : civitai.CivitaiUserCollectionsExtractor,
+    "#results" : (
+        "https://civitai.com/collections/11462456",
+        "https://civitai.com/collections/11453431",
+        "https://civitai.com/collections/11453135",
+        "https://civitai.com/collections/11407164",
+        "https://civitai.com/collections/11405046",
+        "https://civitai.com/collections/11395523",
+        "https://civitai.com/collections/11395467",
+    ),
+},
+
 )
