@@ -12,7 +12,7 @@ __tests__ = (
     "#url"     : "https://imgspice.com/q1taxkhxprrn/58410038_cal022jsp_308191001.jpg.html",
     "#category": ("imagehost", "imgspice", "image"),
     "#class"   : imagehosts.ImgspiceImageExtractor,
-    "#urls"         : "https://img30.imgspice.com/i/03792/q1taxkhxprrn.jpg",
+    "#results"      : "https://img30.imgspice.com/i/03792/q1taxkhxprrn.jpg",
     "#sha1_content" : "f1de8e58a7c2ef747a206a38f96c5623b8a83edc",
 
     "extension": "jpg",
