@@ -10,18 +10,99 @@ import datetime
 
 
 __tests__ = (
+
 {
     "#url"     : "https://mangadex.org/chapter/f946ac53-0b71-4b5d-aeb2-7931b13c4aaa",
     "#class"   : mangadex.MangadexChapterExtractor,
-    "#sha1_metadata": "e86128a79ebe7201b648f1caa828496a2878dc8f",
+    "#count"   : 5,
+
+    "artist"       : ["Oda Eiichiro"],
+    "author"       : ["Oda Eiichiro"],
+    "chapter"      : 6,
+    "chapter_id"   : "f946ac53-0b71-4b5d-aeb2-7931b13c4aaa",
+    "chapter_minor": "",
+    "count"        : 5,
+    "date"         : "dt:2018-02-28 10:42:50",
+    "demographic"  : "shounen",
+    "description"  : "One Piece Omake are short manga chapters originally published in the One Piece Log Books & Databooks.",
+    "extension"    : {"jpg", "png"},
+    "filename"     : str,
+    "group"        : ["KEFI"],
+    "lang"         : "en",
+    "manga"        : "One Piece Omake",
+    "manga_date"   : "dt:2018-06-29 17:22:51",
+    "manga_id"     : "487f1f04-75f3-4a2e-a4af-76e615e32585",
+    "origin"       : "ja",
+    "page"         : range(1, 5),
+    "rating"       : "safe",
+    "status"       : "ongoing",
+    "tags"         : ["Comedy"],
+    "title"        : "The 6th Log - Chopper Man",
+    "volume"       : 0,
+    "year"         : None,
+    "manga_titles" : [
+        "One Piece: Log Book Omake",
+        "One Piece: Mugiwara Theater",
+        "One Piece: Straw Hat Theater",
+        "One Piece: Strawhat Theater",
+    ],
+    "links"        : {
+        "al" : "44414",
+        "kt" : "24849",
+        "mal": "14414",
+    },
 },
 
 {
     "#url"     : "https://mangadex.org/chapter/61a88817-9c29-4281-bdf1-77b3c1be9831",
     "#comment" : "oneshot",
     "#class"   : mangadex.MangadexChapterExtractor,
-    "#count"        : 64,
-    "#sha1_metadata": "d11ed057a919854696853362be35fc0ba7dded4c",
+    "#count"   : 64,
+
+    "artist"       : ["Arakawa Hiromu"],
+    "author"       : ["Arakawa Hiromu"],
+    "chapter"      : 0,
+    "chapter_id"   : "61a88817-9c29-4281-bdf1-77b3c1be9831",
+    "chapter_minor": "",
+    "count"        : 64,
+    "date"         : "dt:2018-03-05 14:36:10",
+    "demographic"  : "shounen",
+    "description"  : "A kunoichi, Henpukumaru, awakens in the mansion of her enemy. She is introduced to the future lord of the mansion, Chiyozuru. Chiyozuru is able to get the unemotional Henpukumaru to smile and react differently than she normally would. But then Henpukumaru's former allies attack one night…",
+    "extension"    : {"jpg", "png"},
+    "filename"     : str,
+    "group"        : ["Illuminati-Manga"],
+    "lang"         : "en",
+    "manga"        : "Souten no Koumori",
+    "manga_date"   : "dt:2018-03-19 10:36:00",
+    "manga_id"     : "f90c4398-8aad-4f51-8a1f-024ca09fdcbc",
+    "origin"       : "ja",
+    "page"         : range(1, 64),
+    "rating"       : "safe",
+    "status"       : "completed",
+    "title"        : "Oneshot",
+    "volume"       : 0,
+    "year"         : 2006,
+    "manga_titles" : [
+        "A Bat in Blue Sky",
+        "Sôten no Kômori",
+        "Soten no Komori",
+        "蒼天の蝙蝠",
+    ],
+    "tags"         : [
+        "Oneshot",
+        "Historical",
+        "Action",
+        "Martial Arts",
+        "Drama",
+        "Tragedy",
+    ],
+    "links"        : {
+        "al" : "30948",
+        "ap" : "souten-no-koumori",
+        "kt" : "2065",
+        "mal": "948",
+        "mu" : "4786",
+    },
 },
 
 {
@@ -52,8 +133,7 @@ __tests__ = (
     "chapter_minor": "",
     "chapter_id"   : str,
     "date"         : datetime.datetime,
-    "lang"         : str,
-    "language"     : str,
+    "lang"         : "iso:lang",
     "artist"       : ["Arakawa Hiromu"],
     "author"       : ["Arakawa Hiromu"],
     "status"       : "completed",
@@ -76,7 +156,6 @@ __tests__ = (
 
     "manga"   : "Souten no Koumori",
     "lang"    : {"fr", "it"},
-    "language": {"French", "Italian"},
 },
 
 {
@@ -156,7 +235,7 @@ __tests__ = (
     "#url"     : "https://mangadex.org/author/7222d0d5-836c-4bf3-9174-72bceade8c87/kotoyama",
     "#class"   : mangadex.MangadexAuthorExtractor,
     "#pattern" : mangadex.MangadexMangaExtractor.pattern,
-    "#count"   : 8,
+    "#count"   : 9,
 },
 
 {
@@ -178,7 +257,7 @@ __tests__ = (
     "cover_id"    : "af3c1690-1e06-4432-909e-3e0f9ee01f68",
     "date"        : "dt:2021-05-24 17:19:13",
     "date_updated": "dt:2021-05-24 17:19:13",
-    "extension"   : "jpg",
+    "extension"   : {"jpg", "png"},
     "filename"    : "af3c1690-1e06-4432-909e-3e0f9ee01f68",
     "lang"        : "ja",
     "manga"       : "Souten no Koumori",
@@ -206,7 +285,7 @@ __tests__ = (
     "cover_id"    : "iso:uuid",
     "date"        : "type:datetime",
     "date_updated": "type:datetime",
-    "extension"   : "jpg",
+    "extension"   : {"jpg", "png"},
     "filename"    : str,
     "lang"        : {"ja", "fa"},
     "manga"       : "Gachiakuta",
